==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/General/hotkey/translations/hotkey_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>ショートカットを変更</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="32"/>
        <source>Press the key combination you want to assign</source>
        <translation>割り当てたいキーの組み合わせを押します</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="52"/>
        <source>Clear</source>
        <translation>消去</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="30"/>
        <source>Global Hotkey Plugin</source>
        <translation>共通ホットキープラグイン</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="50"/>
        <source>About Global Hotkey Plugin</source>
        <translation>共通ホットキープラグインについて</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="51"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>QMMP 通用ホットキープラグイン</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="52"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>このプラグインはマルティミディアキーや共通キーを組み合わせるサポートを加えます</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>共通ホットキープラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Play</source>
        <translation>再生</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Stop</source>
        <translation>終止</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Play/Pause</source>
        <translation>再生/一時停止</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Next</source>
        <translation>次の曲</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Previous</source>
        <translation>前の曲</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Show/Hide</source>
        <translation>隠す/表に出す</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="49"/>
        <source>Volume +</source>
        <translation>音量増加</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="50"/>
        <source>Volume -</source>
        <translation>音量減少</translation>
    </message>
</context>
</TS>

==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/General/hotkey/translations/hotkey_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>ショートカットを変更</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="32"/>
        <source>Press the key combination you want to assign</source>
        <translation>割り当てたいキーの組み合わせを押します</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="52"/>
        <source>Clear</source>
        <translation>消去</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="30"/>
        <source>Global Hotkey Plugin</source>
        <translation>共通ホットキープラグイン</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="50"/>
        <source>About Global Hotkey Plugin</source>
        <translation>共通ホットキープラグインについて</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="51"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>QMMP 通用ホットキープラグイン</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="52"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>このプラグインはマルティミディアキーや共通キーを組み合わせるサポートを加えます</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>共通ホットキープラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Play</source>
        <translation>再生</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Stop</source>
        <translation>終止</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Play/Pause</source>
        <translation>再生/一時停止</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Next</source>
        <translation>次の曲</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Previous</source>
        <translation>前の曲</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Show/Hide</source>
        <translation>隠す/表に出す</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="49"/>
        <source>Volume +</source>
        <translation>音量増加</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="50"/>
        <source>Volume -</source>
        <translation>音量減少</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <source>Forward 5 seconds</source>
        <translation>5 秒すすめる</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <source>Rewind 5 seconds</source>
        <translation>5 秒もどす</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <source>Jump to track</source>
        <translation>トラックを指定して移動</translation>
    </message>
</context>
</TS>
